import React, { useEffect, useState } from 'react';
import { HTMLTable, H1, Tooltip, Dialog, Classes, Intent, Button, Tabs, Tab } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useHistory } from 'react-router-dom';
import { useStores } from '../hooks/useStores';
import ReactJson from 'react-json-view';

const ApiLog = observer(props => {
    const { rootStore } = useStores();

    const [logs, setLogs] = useState([]);
    const [current, setCurrent] = useState(null);
    const [show, setShow] = useState(false);

    useEffect(() => {
        rootStore.loginStore.apiAuthRequest(null, 'sys-api-log', res => {
            setLogs(res.reverse());
        });
    }, [rootStore.loginStore]);

    let { darkTheme } = rootStore.localStore;

    const editorTheme = darkTheme ? 'codeschool' : 'rjv-default';

    function tryParse(json) {
        try {
            return JSON.parse(json);
        } catch {
            return '';
        }
    }

    const showLog = (
        <Dialog
            icon="eye-open"
            isOpen={show}
            onClose={() => {
                setShow(false);
            }}
            title={current && `${current.Username} → ${current.ApiName.substring(1)}`}>
            <div className={Classes.DIALOG_BODY}>
                <Tabs id="Tabs">
                    <Tab
                        id="req"
                        title={'Request'}
                        panel={
                            <ReactJson
                                theme={editorTheme}
                                src={current && tryParse(current.ReqJson)}
                                displayDataTypes={false}
                                displayObjectSize={false}
                                style={{
                                    height: '500px',
                                    border: `1px solid ${darkTheme ? '#262626' : '#BFCCD6'}`,
                                    borderRadius: '0 3px 3px 0',
                                    maxHeight: '500px',
                                    overflow: 'auto',
                                    padding: '10px',
                                    fontFamily: '"Fira Code VF", monospace',
                                }}
                            />
                        }
                    />
                    <Tab
                        id="res"
                        title={'Response'}
                        panel={
                            <ReactJson
                                theme={editorTheme}
                                src={current && tryParse(current.ResJson)}
                                displayDataTypes={false}
                                displayObjectSize={false}
                                style={{
                                    height: '500px',
                                    border: `1px solid ${darkTheme ? '#262626' : '#BFCCD6'}`,
                                    borderRadius: '0 3px 3px 0',
                                    maxHeight: '500px',
                                    overflow: 'auto',
                                    padding: '10px',
                                    fontFamily: '"Fira Code VF", monospace',
                                }}
                            />
                        }
                    />
                </Tabs>
            </div>
            <div className={Classes.DIALOG_FOOTER}>
                <div className={Classes.DIALOG_FOOTER_ACTIONS}>
                    <Button onClick={() => setShow(false)} intent={Intent.PRIMARY}>
                        Закрыть
                    </Button>
                </div>
            </div>
        </Dialog>
    );

    return (
        <>
            {showLog}
            <H1>API requests log</H1>
            <HTMLTable interactive={true}>
                <thead>
                    <tr>
                        <td>#</td>
                        <td>Timestamp</td>
                        <td>Client IP</td>
                        <td>User</td>
                        <td>API</td>
                        <td style={{ textAlign: 'right' }}>Internal time elapsed (ms)</td>
                    </tr>
                </thead>
                <tbody>
                    {logs.map((l, i) => (
                        <tr
                            onClick={e => {
                                setCurrent(l);
                                setShow(true);
                            }}>
                            <td>{++i}</td>
                            <td>
                                {new Date(l.TimeStamp).toLocaleDateString()}{' '}
                                {new Date(l.TimeStamp).toLocaleTimeString()}
                            </td>
                            <td>{l.ClientIP}</td>
                            <td>
                                {l.Username === 'Anonymous' ? (
                                    <span className={'bp3-text-muted'}>{l.Username}</span>
                                ) : (
                                    <Tooltip content={l.Session}>{l.Username}</Tooltip>
                                )}
                            </td>
                            <td>
                                <code>{l.ApiName.substring(1)}</code>
                            </td>
                            <td style={{ textAlign: 'right' }}>{l.MsElapsed === 0 ? '<1' : l.MsElapsed}</td>
                        </tr>
                    ))}
                </tbody>
            </HTMLTable>
        </>
    );
});

export default ApiLog;
