import React, { useEffect } from 'react';
import { H1, HTMLTable, Tab, Tabs, Tag } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import moment from 'moment';
import { useStores } from '../hooks/useStores';

const Calls = observer(props => {
    const { rootStore } = useStores();

    let { getAllCalls, objects } = rootStore.callsStore;
    let { getTypeByID, types } = rootStore.objectsStore;

    useEffect(() => {
        getAllCalls();
    }, [getAllCalls, objects]);

    const typeImage = id => {
        if (types.length) {
            let imgString = getTypeByID(id).IMG_NORMAL;
            return <img src={`data:image/png;base64,${imgString}`} alt={''}/>;
        }
    };

    const calls = (
        <>
            <HTMLTable>
                <thead>
                    <tr>
                        <th></th>
                        <th>Дата</th>
                        <th>Контактное лицо</th>
                        <th>Телефон</th>
                    </tr>
                </thead>
                <tbody>
                    {objects
                        .filter(o => o.ID_TYPE === 1006)
                        .map(o => {
                            return (
                                <tr>
                                    <td>{typeImage(o.ID_TYPE)}</td>
                                    <td style={{ minWidth: 150 }}>
                                        {moment(o.DateOfCreation).format('DD.MM.YY HH:mm:ss')}
                                    </td>
                                    <td>{o.Pars['Контактное лицо']}</td>
                                    <td>
                                        <a href={`tel:${o.Pars['Телефон']}`}>{o.Pars['Телефон']}</a>
                                    </td>
                                </tr>
                            );
                        })}
                </tbody>
            </HTMLTable>
        </>
    );

    const questions = (
        <>
            <HTMLTable>
                <thead>
                    <tr>
                        <th></th>
                        <th>Дата</th>
                        <th>Вопрос</th>
                        <th>Телефон</th>
                        <th>Эл. почта</th>
                    </tr>
                </thead>
                <tbody>
                    {objects
                        .filter(o => o.ID_TYPE === 1005)
                        .map(o => {
                            return (
                                <tr>
                                    <td>{typeImage(o.ID_TYPE)}</td>
                                    <td style={{ minWidth: 150 }}>
                                        {moment(o.DateOfCreation).format('DD.MM.YY HH:mm:ss')}
                                    </td>
                                    <td>{o.Pars['Комментарий заказчика']}</td>
                                    <td>
                                        <a href={`tel:${o.Pars['Телефон']}`}>{o.Pars['Телефон']}</a>
                                    </td>
                                    <td>
                                        <a href={`mailto:${o.Pars['Эл. почта']}`}>{o.Pars['Эл. почта']}</a>
                                    </td>
                                </tr>
                            );
                        })}
                </tbody>
            </HTMLTable>
        </>
    );

    const requests = (
        <>
            <HTMLTable>
                <thead>
                    <tr>
                        <th></th>
                        <th>Дата</th>
                        <th>Услуга</th>
                        <th>Компания</th>
                        <th>Контактное лицо</th>
                        <th>Телефон</th>
                        <th>Эл. почта</th>
                        <th>Комментарий</th>
                    </tr>
                </thead>
                <tbody>
                    {objects
                        .filter(o => o.ID_TYPE === 1004)
                        .map(o => {
                            return (
                                <tr>
                                    <td>{typeImage(o.ID_TYPE)}</td>
                                    <td style={{ minWidth: 150 }}>
                                        {moment(o.DateOfCreation).format('DD.MM.YY HH:mm:ss')}
                                    </td>
                                    <td>{o.Pars['Услуга']}</td>
                                    <td>{o.Pars['Заказчик']}</td>
                                    <td>{o.Pars['Контактное лицо']}</td>
                                    <td>
                                        <a href={`tel:${o.Pars['Телефон']}`}>{o.Pars['Телефон']}</a>
                                    </td>
                                    <td>
                                        <a href={`mailto:${o.Pars['Эл. почта']}`}>{o.Pars['Эл. почта']}</a>
                                    </td>
                                    <td>{o.Pars['Комментарий заказчика']}</td>
                                </tr>
                            );
                        })}
                </tbody>
            </HTMLTable>
        </>
    );

    return (
        <>
            <H1>Звонки и заявки</H1>
            <Tabs id="Tabs">
                <Tab
                    id="calls"
                    title={
                        <>
                            <div style={{ marginBottom: '2px' }}>
                                <span style={{ marginRight: '4px' }}>Звонки</span>
                                <Tag minimal>{objects.filter(o => o.ID_TYPE === 1006).length}</Tag>
                            </div>
                        </>
                    }
                    panel={calls}
                />
                <Tab
                    id="questions"
                    title={
                        <>
                            <div style={{ marginBottom: '2px' }}>
                                <span style={{ marginRight: '4px' }}>Вопросы</span>
                                <Tag minimal>{objects.filter(o => o.ID_TYPE === 1005).length}</Tag>
                            </div>
                        </>
                    }
                    panel={questions}
                />
                <Tab
                    id="requests"
                    title={
                        <>
                            <div style={{ marginBottom: '2px' }}>
                                <span style={{ marginRight: '4px' }}>Заявки</span>
                                <Tag minimal>{objects.filter(o => o.ID_TYPE === 1004).length}</Tag>
                            </div>
                        </>
                    }
                    panel={requests}
                />
            </Tabs>
        </>
    );
});

export default Calls;
