import { Button, H1, HTMLTable } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';
import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import { useStores } from '../hooks/useStores';
import CategoryEditDialog from './CategoryEditDialog';

const Categories = observer(props => {
    const { rootStore } = useStores();
    let { categories } = rootStore.objectsStore;

    const [currentCat, setCurrentCat] = useState({});
    const [open, setOpen] = useState(false);
    const [create, setCreate] = useState(false);

    const catsList = (
        <>
            <Button
            style={{width: '100px'}}
                icon={'new-object'}
                onClick={e => {
                    setCurrentCat(null);
                    setCreate(true);
                    setOpen(true);
                }}>Создать...</Button>
            <HTMLTable interactive={true}>
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Короткое имя</th>
                        <th>Имя</th>
                        <th>Таблица</th>
                    </tr>
                </thead>
                <tbody>
                    {categories.map(c => {
                        return (
                            <tr
                                key={c.ID_CAT}
                                onClick={e => {
                                    setCurrentCat(c);
                                    setCreate(false);
                                    setOpen(true);
                                }}>
                                <td>{c.ID_CAT}</td>
                                <td>
                                    <Link to={`/objects/${c.ID_CAT}`}>{c.NAME_SHORT}</Link>
                                </td>
                                <td>{c.NAME}</td>
                                <td>{c.DB_TBL_NAME}</td>
                            </tr>
                        );
                    })}
                </tbody>
            </HTMLTable>
        </>
    );

    return (
        <>
            <H1>Категории</H1>
            {catsList}
            <CategoryEditDialog isOpen={open} create={create} onClose={() => setOpen(false)} category={currentCat} />
        </>
    );
});

export default Categories;
