import React, { useState, useEffect } from 'react';
import { useStores } from '../../hooks/useStores';
import { observer } from 'mobx-react-lite';
import { useParams } from 'react-router-dom';
import { Tree, Classes, Button } from '@blueprintjs/core';
import CytoscapeComponent from 'react-cytoscapejs';

import { Scrollbar } from "react-scrollbars-custom";

import './Experiments.css';

const ExperimentOne = observer(props => {
    const { rootStore } = useStores();
    let { nodes, elements, lastNodeID, setData, setElements, setExpand, setCollapse } = rootStore.experimentsStore;
    let { fileID } = useParams();

    const handleExpand = (nodeData) => {
        console.log("handleExpand: nodeData.id=" + nodeData.id);
        setExpand(nodeData, fileID);
    };

    const handleCollapse = (nodeData) => {
        console.log("handleCollapse: nodeData.id=" + nodeData.id);
        setCollapse(nodeData.id);
    };

    const handleNodeClick = (nodeData, _nodePath, e) => {
        console.log("NodeClick: " + _nodePath + " id=" + nodeData.id);
        rootStore.loginStore.apiAuthRequest({ FileID: fileID, SDataID: Number(nodeData.key) },
            "api-sdata-gettsep",
            res => {
                setElements(res.elements);
            });
    };

    const bClick = (e) => {
        console.log("bClick");

        rootStore.loginStore.apiAuthRequest({ FileID: fileID },
            "api-sdata-openfile",
            res => { setData(res.Nodes, res.LastNodeID); }
        );
    };

    //const elements = [
    //    { data: { id: 'one', label: 'Node 1' }, position: { x: 0, y: 0 } },
    //    { data: { id: 'two', label: 'Наименование длинного цехозахода' }, position: { x: 100, y: 0 } },
    //    { data: { id: 'line1', source: 'one', target: 'two', label: 'Edge from Node1 to Node2' }, }
    //];

    const style = [
        {
            selector: 'node',
            style: {
                label: 'data(label)',
                width: 100,
                height: 40,
                shape: 'round-rectangle',
                "font-size": "10pt",
                "text-halign": "center",
                "text-valign": "center",
                "text-wrap": "wrap",
                "text-max-width": 100
            },
        },
        {
            selector: 'edge',
            style: {
                /* label: 'data(label)', */
                "width": 1,
                "curve-style": "bezier" /*"segments"*/ /*"bezier"*/,
                "source-arrow-shape": "circle",
                "target-arrow-shape": "vee" /*"triangle-backcurve"*/ /* "vee" */
            }
        }];

    const layout = {
        name: 'grid',

        fit: true, // whether to fit the viewport to the graph
        padding: 30, // padding used on fit
        boundingBox: undefined, // constrain layout bounds; { x1, y1, x2, y2 } or { x1, y1, w, h }
        avoidOverlap: true, // prevents node overlap, may overflow boundingBox if not enough space
        avoidOverlapPadding: 10, // extra spacing around nodes when avoidOverlap: true
        nodeDimensionsIncludeLabels: false, // Excludes the label when calculating node bounding boxes for the layout algorithm
        spacingFactor: undefined, // Applies a multiplicative factor (>0) to expand or compress the overall area that the nodes take up
        condense: false, // uses all available space on false, uses minimal space on true
        rows: undefined, // force num of rows in the grid
        cols: undefined, // force num of columns in the grid
        position: function (node) { }, // returns { row, col } for element
        sort: undefined, // a sorting function to order the nodes; e.g. function(a, b){ return a.data('weight') - b.data('weight') }
        animate: true, // whether to transition the node positions
        animationDuration: 500, // duration of animation in ms if enabled
        animationEasing: undefined, // easing of animation if enabled
        animateFilter: function (node, i) { return true; }, // a function that determines whether the node should be animated.  All nodes animated by default on animate enabled.  Non-animated nodes are positioned immediately when the layout starts
        ready: undefined, // callback on layoutready
        stop: undefined, // callback on layoutstop
        transform: function (node, position) { return position; } // transform a given node position. Useful for changing flow direction in discrete layouts
    };

    return (
        <>
            <div className="main-view">

                <div className="left-panel in-line-div">
                    <Button className="load-button" onClick={bClick} text={"Загрузить файл: " + fileID} />

                    <Scrollbar className="deep-scroll-bar">
                        <Tree
                            contents={nodes}
                            onNodeClick={handleNodeClick}
                            onNodeCollapse={handleCollapse}
                            onNodeExpand={handleExpand}
                            className={Classes.ELEVATION_0}
                        />
                    </Scrollbar>

                </div>

                <div className="right-panel in-line-div">
                    <CytoscapeComponent
                        className="graph-component"
                        elements={elements}
                        layout={layout}
                        stylesheet={style}
                    />
                </div>

                <br className="in-line-clear" />
            </div>

        </>
    );

});

export default ExperimentOne;
