import React, { useState, useEffect } from 'react';
import { H1, HTMLTable, Card, InputGroup, Button, ControlGroup, Callout, Intent, FormGroup, ButtonGroup, Icon } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import moment from 'moment';
import { useStores } from '../hooks/useStores';

const FavServers = observer(props => {
    const { rootStore } = useStores();

    let [currentServer, setCurrentServer] = useState('');
    let [currentServerOk, setCurrentServerOk] = useState(null);
    let [calloutText, setCalloutText] = useState('');

    let { servers, getServers, addServer, clearServers, checkServer, checkServers, removeServer } = rootStore.serversStore;

    function showStatus(server) {
        if (server.status) {
            return <><Icon icon="tick" intent={Intent.SUCCESS} /><span> {server.result}</span></>
        } else if (server.status === undefined) {
            return <span>--</span>
        } else {
            return <><Icon icon="cross" intent={Intent.DANGER} /><span> {server.result}</span></>
        }
    }

    useEffect(() => {
        getServers();
    }, []);

    const serversList = <>
        <div><HTMLTable interactive={true}>
            <thead>
                <th>№</th>
                <th>Сервер</th>
                <th>Действия</th>
                <th>Ответ</th>
                <th>Последняя проверка</th>
            </thead>
            <tbody>
                {servers.map((s, index) => {
                    return <tr>
                        <td key={index}>{index + 1}</td>
                        <td>{s.server}</td>
                        <td><ButtonGroup minimal={true}>
                            <Button icon='remove' onClick={() => removeServer(s.server)} />
                            <Button icon='diagnosis' onClick={() => checkServer(s.server)} />
                        </ButtonGroup></td>
                        <td>{showStatus(s)}</td>
                        <td>{moment(s.date).format('DD.MM.YY HH:mm:ss')}</td>
                    </tr>
                })}
            </tbody>
        </HTMLTable></div>
    </>

    function isValidHttpUrl(string) {
        let url;
        try {
            url = new URL(string);
        } catch (_) {
            return false;
        }

        return url.protocol === "http:" || url.protocol === "https:";
    }

    let serverFailed = <FormGroup>
        <Callout intent={Intent.WARNING}>Сервер <a href={currentServer}>{currentServer}</a> недоступен ({calloutText})</Callout>
    </FormGroup>

    let serverOk = <FormGroup>
        <Callout intent={Intent.SUCCESS}>{calloutText}</Callout>
    </FormGroup>

    function checkCurrentServer(server) {
        rootStore.loginStore.apiUnAuthCustomRequest(null, "sys-status", server, (res) => {
            setCurrentServerOk(true); setCalloutText(res.ServerNameFull)
        }, (err) => { setCurrentServerOk(false); setCalloutText(err) });
    }

    const addServerForm = <>
        <Card>
            <h5>Добавить</h5>
            <FormGroup>
                <ControlGroup>
                    <InputGroup
                        placeholder="http://server:port"
                        value={currentServer}
                        onChange={(e) => { setCurrentServer(e.target.value); setCurrentServerOk(null); }}
                    />
                    <Button text="Тест" icon='diagnosis' disabled={!(!!currentServer)} onClick={() => checkCurrentServer(currentServer)} />
                    <Button text="Добавить" icon='add' disabled={!(!!currentServer && !!isValidHttpUrl(currentServer))}
                        onClick={() => { addServer(currentServer); setCurrentServer(''); }} />
                </ControlGroup>
            </FormGroup>
            {currentServerOk && serverOk}
            {currentServerOk === false && serverFailed}
            <h5>Действия</h5>
            <ButtonGroup>
                <Button icon="diagnosis" disabled={(servers.length === 0)} onClick={checkServers}>Проверить все</Button>
                <Button icon="cross" intent={Intent.DANGER} disabled={(servers.length === 0)} onClick={clearServers}>Очистить список</Button>
            </ButtonGroup>
        </Card>
    </>

    return (<>
        <H1>Избранные сервера</H1>
        <p>Эти настройки сохраняются для всех пользователей компьютера</p>
        {serversList}
        {addServerForm}
    </>
    );
});

export default FavServers;
