import React, { useEffect, useState } from 'react';
import { Button, Classes, Intent, TextArea, Dialog } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useStores } from '../hooks/useStores';
import html2canvas from 'html2canvas';

const Feedback = observer(props => {
    const { rootStore } = useStores();
    const { isLoggedIn, sendFeedback } = rootStore.loginStore;

    let [open, setOpen] = useState(false);
    let [pngUrl, setPngUrl] = useState(null);
    let [text, setText] = useState('');
    let [sending, setSending] = useState(false);

    useEffect(() => {
        if (open) {
            const overflow = document.body.style.overflow;
            document.body.style.overflow = 'visible';
            html2canvas(document.body).then(canvas => {
                setPngUrl(canvas.toDataURL());
                document.body.style.overflow = overflow;
            });
        }
    }, [open]);

    const button = <Button className={Classes.MINIMAL} icon="comment" text="Фидбек" onClick={e => setOpen(true)} />;

    const dialog = (
        <Dialog icon="comment" isOpen={open} onClose={e => setOpen(false)} title="Обратная связь">
            <div className={Classes.DIALOG_BODY}>
                {!!pngUrl && (
                    <img
                        src={pngUrl}
                        width={'100%'}
                        alt="Feedback screenshot"
                        style={{ boxShadow: '0px 0px 14px 0px rgba(0,0,0,0.33)', marginBottom: 15 }}
                    />
                )}
                <div>
                    <TextArea
                        style={{ width: '100%' }}
                        placeholder={'Опишите проблему'}
                        growVertically={true}
                        large={false}
                        intent={Intent.PRIMARY}
                        onChange={e => setText(e.target.value)}
                        value={text}
                    />
                </div>
            </div>
            <div className={Classes.DIALOG_FOOTER}>
                <div className={Classes.DIALOG_FOOTER_ACTIONS}>
                    <Button onClick={e => setOpen(false)}>Отмена</Button>
                    <Button
                        loading={sending}
                        onClick={e => {
                            sendFeedback(text, pngUrl, () => {
                                setSending(false);
                                setOpen(false);
                            });
                            setText('');
                            setSending(true);
                        }}
                        intent={Intent.PRIMARY}>
                        Отправить
                    </Button>
                </div>
            </div>
        </Dialog>
    );

    return (
        <>
            {dialog}
            {isLoggedIn ? button : null}
        </>
    );
});

export default Feedback;
