import React, { useState } from 'react';
import { Button, H5, Intent } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { NavLink } from 'react-router-dom';
import { useStores } from '../hooks/useStores';

const LeftMenu = observer(props => {
    const { rootStore } = useStores();
    const [showMenu, setShowMenu] = useState(true);

    let { darkTheme } = rootStore.localStore;

    const menuStyle = {
        padding: 20,
        background: darkTheme ? '#30404D' : '#EBF1F5',
        display: 'flex',
        flexDirection: 'column',
        maxHeight: !showMenu ? '75px' : '100vh'
    };

    const listStyle = {
        listStyleType: 'none',
        padding: 0,
        lineHeight: 1.4,
    };

    const liStyle = {
        marginBottom: 4,
    };

    const sectionStyle = {
        color: '#5C7080',
        fontVariant: 'all-small-caps',
    };

    const activeStyle = {
        fontWeight: 'bold',
        color: darkTheme ? '#FFFFFF' : '#30404D',
    };

    const menu = [
        {
            section: 'Администрация',
            links: [
                { link: '/admin/db', caption: 'Структура БД' },
                { link: '/users', caption: 'Пользователи' },
                { link: '/info', caption: 'О сервере' },
                { link: '/logs', caption: 'Логи' },
                { link: '/apiref', caption: 'API Reference' },
                { link: '/apilog', caption: 'API Logs' },
                { link: '/servers', caption: 'Избранные сервера' },
            ],
        },
        {
            section: 'Объекты',
            links: [
                { link: '/categories', caption: 'Категории' },
                { link: '/types', caption: 'Типы объектов' },
                { link: '/relations', caption: 'Отношения' },
                { link: '/objects', caption: 'Объекты' },
            ],
        },
        {
            section: 'Тесты',
            links: [
                { link: '/permstest', caption: 'Тест разрешений (modDynext)' },
                { link: '/permstest2', caption: 'Тест разрешений (NO_SUCH_PERM)' },
                { link: '/apitest', caption: 'Тест АПИ' },
                { link: '/md', caption: 'Тест Markdown' },
            ],
        },
        {
            section: 'CMS',
            links: [
                { link: '/calls', caption: 'Звонки' },
                { link: '/pages', caption: 'Редактор страниц' },
            ],
        },
    ];

    return (
        <>
            <div style={menuStyle} className={'main-menu'}>
                <Button
                    className={'main-menu-button'}
                    intent={Intent.PRIMARY}
                    icon="menu"
                    onClick={() => setShowMenu(!showMenu)}
                    style={{ marginBottom: '1rem' }}>
                    Меню
                </Button>
                {showMenu && (
                    <nav>
                        {menu.map(m => (
                            <>
                                <H5 style={sectionStyle}>{m.section}</H5>
                                <ul style={listStyle}>
                                    {m.links.map(l => (
                                        <li key={l.link} style={liStyle}>
                                            <NavLink activeStyle={activeStyle} to={l.link}>
                                                {l.caption}
                                            </NavLink>
                                        </li>
                                    ))}
                                </ul>
                            </>
                        ))}
                    </nav>
                )}
            </div>
        </>
    );
});

export default LeftMenu;
