import React, { useEffect } from 'react';
import { HTMLTable, Tabs, Tab, Checkbox, Tag, Tooltip } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { dateTime } from '../utils/dateTime';
import { Link, useParams, useHistory } from 'react-router-dom';
import { useStores } from '../hooks/useStores';
import LongSpan from './LongSpan';

const ObjectView = observer(props => {
    const { rootStore } = useStores();

    let {
        currentObject,
        getTypeByID,
        getObject,
        getPars,
        getObjectRelations,
        categories,
        types,
        fetching,
    } = rootStore.objectsStore;

    let { catID, objID } = useParams();

    useEffect(() => {
        getObject(objID, catID);
        getPars(objID, catID);
        getObjectRelations(objID, catID);
    }, [catID, objID, getObject, getPars, getObjectRelations]);

    let history = useHistory();

    const typeImg = () => {
        let type = getTypeByID(currentObject.ID_TYPE);
        if (type) {
            return <img src={`data:image/png;base64,${type.IMG_NORMAL}`} alt={''} style={{ height: '1ch' }} />;
        } else {
            return null;
        }
    };

    const typeImage = id => {
        if (types.length) {
            let imgString = getTypeByID(id).IMG_NORMAL;
            return <img src={`data:image/png;base64,${imgString}`} alt="" />;
        }
    };

    const cat = categories.filter(c => c.ID_CAT === currentObject.ID_CAT)[0];
    const type = types.filter(c => c.ID_TYPE === currentObject.ID_TYPE)[0];

    const info = !!cat && !!type && (
        <>
            <HTMLTable>
                <thead>
                    <tr>
                        <th>Параметр</th>
                        <th>Значение</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td>ID</td>
                        <td>{currentObject.ID}</td>
                    </tr>
                    <tr>
                        <td>Тип</td>
                        <td>
                            {typeImg()} {currentObject.ID_TYPE} ({type.GROUP_NAME} &#8594; {type.NAME})
                        </td>
                    </tr>
                    <tr>
                        <td>Категория</td>
                        <td>
                            <Tooltip content={`Открыть категорию «${cat.NAME_SHORT}»`}>
                                <Link to={`/objects/${currentObject.ID_CAT}`} target={'_blank'}>
                                    {currentObject.ID_CAT}
                                </Link>
                            </Tooltip>
                            {' '}({cat.NAME_SHORT})
                        </td>
                    </tr>
                    <tr>
                        <td>Наименование</td>
                        <td>{currentObject.NAME}</td>
                    </tr>
                    <tr>
                        <td>Обозначение</td>
                        <td>
                            <code>{currentObject.SPEC}</code>
                        </td>
                    </tr>
                    <tr>
                        <td>Дата создания</td>
                        <td>{dateTime(currentObject.DateOfCreation)}</td>
                    </tr>
                    <tr>
                        <td>Дата изменения</td>
                        <td>{dateTime(currentObject.DateOfModification)}</td>
                    </tr>
                    <tr>
                        <td>Заблокирован</td>
                        <td>
                            <Checkbox disabled={true} checked={currentObject.BLOCKED} />
                        </td>
                    </tr>
                    <tr>
                        <td>Удален</td>
                        <td>
                            <Checkbox disabled={true} checked={currentObject.DELETED} />
                        </td>
                    </tr>
                </tbody>
            </HTMLTable>
        </>
    );

    const pars = !!currentObject.Pars && (
        <>
            <HTMLTable>
                <thead>
                    <tr>
                        <th>Параметр</th>
                        <th>Значение</th>
                    </tr>
                </thead>
                <tbody>
                    {Object.entries(currentObject.Pars).map(([key, value]) => {
                        return (
                            <tr>
                                <td style={{ whiteSpace: 'nowrap' }}>{key}</td>
                                <td>
                                    <LongSpan text={value.toString()}></LongSpan>
                                </td>
                            </tr>
                        );
                    })}
                </tbody>
            </HTMLTable>
        </>
    );

    const relations = !!currentObject.relsArr && !fetching && (
        <>
            {currentObject.relsArr.map(r => {
                return (
                    <>
                        <h2>{r.name}</h2>
                        <HTMLTable>
                            <thead>
                                <tr>
                                    <th></th>
                                    <th>ID</th>
                                    <th>ID_CAT</th>
                                    <th>ID_TYPE</th>
                                    <th>Обозначение</th>
                                    <th>Наименование</th>
                                    <th>Дата создания</th>
                                    <th>Дата изменения</th>
                                </tr>
                            </thead>
                            <tbody>
                                {r.objects.map(o => {
                                    return (
                                        !!o.object && (
                                            <tr>
                                                <td>{typeImage(o.object.ID_TYPE)}</td>
                                                <td>{o.object.ID}</td>
                                                <td>{o.object.ID_CAT}</td>
                                                <td>{o.object.ID_TYPE}</td>
                                                <td>
                                                    <code>
                                                        <Link to={`/objects/${o.object.ID_CAT}/${o.object.ID}`}>
                                                            {o.object.SPEC}
                                                        </Link>
                                                    </code>
                                                </td>
                                                <td>{o.object.NAME}</td>
                                                <td style={{ minWidth: 150 }}>{dateTime(o.object.DateOfCreation)}</td>
                                                <td style={{ minWidth: 150 }}>
                                                    {dateTime(o.object.DateOfModification)}
                                                </td>
                                            </tr>
                                        )
                                    );
                                })}
                            </tbody>
                        </HTMLTable>
                    </>
                );
            })}
        </>
    );

    return (
        <>
            <ul className="bp3-breadcrumbs">
                <li>
                    <Link className="bp3-breadcrumb" to="/objects">
                        Объекты
                    </Link>
                </li>
                <li>
                    <div style={{ marginRight: '.2rem' }}>{typeImg()}</div>
                    <span className="bp3-breadcrumb bp3-breadcrumb-current">
                        <code>{currentObject.SPEC}</code>&nbsp;&laquo;{currentObject.NAME}&raquo;
                    </span>
                </li>
            </ul>
            <Tabs id="tabs">
                <Tab
                    id="info"
                    title={
                        <div style={{ marginBottom: '2px' }}>
                            <span style={{ marginRight: '4px' }}>Информация</span>
                        </div>
                    }
                    panel={info}
                />
                <Tab
                    id="pars"
                    title={
                        <>
                            <div style={{ marginBottom: '2px' }}>
                                <span style={{ marginRight: '4px' }}>Параметры</span>
                                <Tag minimal>{!!currentObject.Pars ? Object.keys(currentObject.Pars).length : '0'}</Tag>
                            </div>
                        </>
                    }
                    panel={pars}
                />
                <Tab
                    id="rels"
                    title={
                        <>
                            <div style={{ marginBottom: '2px' }}>
                                <span style={{ marginRight: '4px' }}>Отношения</span>
                                <Tag minimal>{!!currentObject.relsArr ? currentObject.relsArr.flat().length : '0'}</Tag>
                            </div>
                        </>
                    }
                    panel={relations}
                />
            </Tabs>
        </>
    );
});

export default ObjectView;
