import React, { useEffect } from 'react';
import { H1, HTMLTable, Tooltip, Classes } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useStores } from '../hooks/useStores';

const ObjectTypes = observer(props => {
    const { rootStore } = useStores();
    let { types, getTypes } = rootStore.objectsStore;

    useEffect(() => {
        getTypes();
    }, [])

    const isCyr = (term) => /[а-яА-ЯЁё]/.test(term);
    const isEng = (term) => /[a-zA-Z]/.test(term);

    const toolTip = (t) =>
        <Tooltip className={Classes.TOOLTIP_INDICATOR}
            content={`Буква: ${t.CHARACTER} ${isCyr(t.CHARACTER) ? '🇷🇺' : isEng(t.CHARACTER) ? '🇬🇧' : ''}`} >
            {t.ID_TYPE}
        </Tooltip>

    const typesList = <>
        <HTMLTable interactive={true}>
            <thead>
                <th></th>
                <th>ID</th>
                <th>Группа</th>
                <th>Имя</th>
                <th>Описание</th>
            </thead>
            <tbody>
                {types.map(t => {
                    return <tr>
                        <td>{<img src={`data:image/png;base64,${t.IMG_NORMAL}`} />}</td>
                        <td>{toolTip(t)}</td>
                        <td>{t.GROUP_NAME}</td>
                        <td>{t.NAME}</td>
                        <td>{t.DESCRIPTION}</td>
                        <td></td>
                    </tr>
                })}
            </tbody>
        </HTMLTable>
    </>


    return (<>
        <H1>Типы объектов</H1>
        {typesList}
    </>
    );
});

export default ObjectTypes;
