import React, { useEffect, useState } from 'react';
import { TextArea, Button, MenuItem, FormGroup, InputGroup, H1, ButtonGroup, Intent } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { Select } from '@blueprintjs/select';
import { useStores } from '../hooks/useStores';
import { createViewModel } from 'mobx-utils';
import CodeEditor from './CodeEditor';

const PageEdit = observer(props => {
    const { rootStore } = useStores();
    let { getAllPages, pages, setCurrentPage, currentPage, isPageDirty } = rootStore.pagesStore;

    useEffect(() => {
        getAllPages();
    }, [getAllPages]);

    function itemRenderer(item, { modifiers, handleClick, query }) {
        return (
            <MenuItem
                active={modifiers.active}
                icon={'document'}
                key={item.ID}
                onClick={handleClick}
                text={isPageDirty(item) ? item.NAME + '*' : item.NAME}
                label={item.ID}
                shouldDismissPopover
                //text={highlightText(item.NAME, query)}
            />
        );
    }

    const handleItemListPredicate = (query, items) => {
        return pages.filter(c => c.NAME.toLowerCase().includes(query.toLowerCase()));
    };

    const handleElementSelect = page => {
        setCurrentPage(page);
    };

    const pageName = () => {
        if (currentPage) {
            return isPageDirty(currentPage) ? currentPage.NAME + '*' : currentPage.NAME;
        } else {
            return 'Выберите страницу...';
        }
    };

    return (
        <>
            <H1>Редактор страниц</H1>
            {pages.length && (
                <>
                    <FormGroup>
                        <Select
                            items={pages}
                            itemRenderer={itemRenderer}
                            onItemSelect={handleElementSelect}
                            itemPredicate={handleItemListPredicate}
                            noResults={<MenuItem disabled={true} text="No results." />}>
                            <Button rightIcon="caret-down" text={pageName()} />
                        </Select>
                    </FormGroup>
                    {currentPage && (
                        <>
                            <FormGroup label="Заголовок">
                                <InputGroup
                                    label="Заголовок"
                                    onChange={e => (currentPage['Заголовок'] = e.target.value)}
                                    value={currentPage['Заголовок']}
                                />
                            </FormGroup>

                            <FormGroup label="Заголовок" labelInfo={'англ.'}>
                                <InputGroup
                                    onChange={e => (currentPage['Заголовок en'] = e.target.value)}
                                    value={currentPage['Заголовок en']}
                                />
                            </FormGroup>

                            <FormGroup label="Услуга">
                                <InputGroup
                                    onChange={e => (currentPage['Услуга'] = e.target.value)}
                                    value={currentPage['Услуга']}
                                />
                            </FormGroup>

                                <CodeEditor
                                    value={ currentPage['Тело страницы'] }
                                    onChange={ (ev, value) => {
                                            currentPage['Тело страницы'] = value;
                                        }
                                    }
                                />

                                { /* <TextArea
                                    fill={true}
                                    onChange={e => (currentPage['Тело страницы'] = e.target.value)}
                                    value={currentPage['Тело страницы']}
                                   /> */}

                            <FormGroup>
                                <ButtonGroup>
                                    <Button disabled={!currentPage.isDirty} intent={Intent.PRIMARY} onClick={null}>
                                        Сохранить
                                    </Button>
                                    <Button disabled={!currentPage.isDirty} onClick={() => currentPage.reset()}>
                                        Отменить
                                    </Button>
                                </ButtonGroup>
                            </FormGroup>
                        </>
                    )}
                </>
            )}
        </>
    );
});

export default PageEdit;
