import React, { useEffect } from 'react';
import { Route, useHistory } from 'react-router-dom';
import { observer } from 'mobx-react-lite';import { Button, Callout, Intent } from '@blueprintjs/core';
import { useStores } from '../hooks/useStores';

const PrivateRoute = observer(({ component: Component, permission, ...rest }) => {
    let history = useHistory();

    const { rootStore } = useStores();
    let { isLoggedIn, hasPermission, getUserInfo, isAdmin, tryLogin, loading } = rootStore.loginStore;

    useEffect(() => {
        getUserInfo();
    }, [getUserInfo]);

    const cardStyle = {
        width: 400,
        alignSelf: 'center',
        margin: 'auto',
    };

    let hasPerm = hasPermission(permission);
    // TODO сделать спиннер
    let alert = (
        <Callout style={cardStyle} intent={Intent.WARNING}>
            <p>У вас нет разрешения на доступ к этой странице</p>
            {isAdmin && (
                <p>
                    Требуется разрешение <code>{permission}</code>
                </p>
            )}
            {<Button onClick={() => history.goBack()}>Назад</Button>}
        </Callout>
    );

    function f(props) {
        if (isLoggedIn) {
            if (!permission) {
                return <Component permission={permission} {...props} />;
            } else if (hasPerm) {
                return <Component permission={permission} {...props} />;
            } else {
                return alert;
            }
        } else {
            tryLogin(result => {
                if (!result)
                    return history.push({
                        pathname: '/login',
                        state: { from: props.location, reason: 'Сессия истекла' },
                    });
                if (result) {
                    if (!permission) {
                        return <Component permission={permission} {...props} />;
                    } else if (hasPerm) {
                        return <Component permission={permission} {...props} />;
                    } else {
                        return alert;
                    }
                }
            });
        }
    }

    return <Route {...rest} render={props => f(props)} />;
});

export default PrivateRoute;
