import React from 'react';
import { Button, FormGroup, Menu, MenuDivider, MenuItem, Popover, Position, TagInput } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useStores } from '../hooks/useStores';
import { toJS } from 'mobx';

const SelectCategories = observer(props => {
    const { rootStore } = useStores();
    let { categories, selectedCategories } = rootStore.objectsStore;

    const values = selectedCategories.map(c => c.NAME_SHORT);

    const handleCatSelect = item => {
        if (selectedCategories.includes(item)) {
            selectedCategories.remove(item);
        } else {
            selectedCategories.push(item);
        }
    };

    const handleSelectAll = () => {
        selectedCategories.clear();
        categories.map(c => selectedCategories.push(c));
    };

    const handleSelectNone = () => {
        selectedCategories.clear();
    };

    const handleSelectInverse = () => {
        let cats = toJS(selectedCategories.map(c => c.ID_CAT));
        selectedCategories.clear();

        categories.forEach(c => {
            if (!cats.includes(c.ID_CAT)) {
                selectedCategories.push(c);
            }
        });
    };

    const handleTagAdd = tags => {
        for (let tag of tags) {
            let cat = categories.find(c => c.NAME_SHORT === tag || c.NAME === tag || c.ID_CAT === Number(tag));
            if (cat && !selectedCategories.includes(cat)) {
                selectedCategories.push(cat);
            }
        }
    };

    const handleTagRemove = tag => {
        let cat = selectedCategories.find(c => c.NAME_SHORT === tag);
        selectedCategories.remove(cat);
    };

    const menu = (
        <Menu>
            <MenuDivider title="Выбрать..." />
            <MenuItem
                text={'Все'}
                icon={'unresolve'}
                onClick={handleSelectAll}
                disabled={categories.length === selectedCategories.length}
                shouldDismissPopover={false}
            />
            <MenuItem
                text={'Ни одной'}
                icon={'intersection'}
                onClick={handleSelectNone}
                disabled={selectedCategories.length === 0}
                shouldDismissPopover={false}
            />
            <MenuItem
                text={'Инвертировать'}
                icon={'right-join'}
                onClick={handleSelectInverse}
                shouldDismissPopover={false}
            />
            <MenuDivider />
            {categories.map(c => {
                return (
                    <MenuItem
                        text={c.NAME}
                        label={c.ID_CAT}
                        icon={selectedCategories.includes(c) ? 'tick' : 'blank'}
                        onClick={e => handleCatSelect(c)}
                        shouldDismissPopover={false}
                    />
                );
            })}
        </Menu>
    );

    return (
        <>
            <FormGroup
                label={'Категории'}
                labelInfo={`${selectedCategories.length}/${categories.length}`}
                helperText={'Вводите ID или имена категорий, разделенные запятыми'}>
                <div style={{ display: 'flex', flexDirection: 'row' }}>
                    <div style={{ marginRight: '.3em' }}>
                        <TagInput
                            values={values}
                            onAdd={handleTagAdd}
                            onRemove={handleTagRemove}
                            tagProps={{ minimal: true }}
                        />
                    </div>
                    <div>
                        <Popover content={menu} position={Position.RIGHT_BOTTOM} canEscapeKeyClose={true}>
                            <Button icon="filter-list" text="Выбрать..." />
                        </Popover>
                    </div>
                </div>
            </FormGroup>
        </>
    );
});

export default SelectCategories;
