import { Breadcrumb, Breadcrumbs, ControlGroup, FormGroup, ProgressBar, Switch, TextArea } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';
import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import { useStores } from '../hooks/useStores';
import ServerLogFancy from './ServerLogFancy';

const ServerLog = observer(props => {

    const [log, setLog] = useState("");
    const [showFancy, setShowFancy] = useState(false);
    const [loading, setLoading] = useState(false);
    let [percent, setPercent] = useState(0);

    const { rootStore } = useStores();

    let { filename } = useParams();

    const BREADCRUMBS = [
        { href: "/logs", icon: "folder-close", text: "Логи" },
        { href: `/logs/${filename}`, icon: "document", text: filename },
    ];

    useEffect(() => {
        getLog();
    }, []);

    function getLog() {
        setLoading(true);
        const req = { FileName: filename };
        rootStore.loginStore.apiAuthRequest(req, "api-log-getfilecontent", (res) => { setLog(res.FileContent); setLoading(false); },
            null, null, (e) => { setPercent(e / 100) });
    }

    const renderCurrentBreadcrumb = ({ text, ...restProps }) => {
        return <Breadcrumb {...restProps}>{text}</Breadcrumb>;
    };

    const progressCard = {
        width: '500px',
        alignSelf: 'center',
        margin: 'auto'
    }

    return (<>
        <Breadcrumbs
            currentBreadcrumbRenderer={renderCurrentBreadcrumb}
            items={BREADCRUMBS}
        />
        {loading ?
            <div style={progressCard}>
                <ProgressBar value={percent} animate={true}/>
            </div> : <>
                <FormGroup>
                    <ControlGroup>
                        <Switch checked={showFancy} label="Табличный вид" onChange={(_) => setShowFancy(!showFancy)} />
                    </ControlGroup>
                </FormGroup>
                {!showFancy && <TextArea fill={true} readOnly={true} value={log} />}
                {showFancy && <ServerLogFancy log={log} />}</>}
    </>
    );
});

export default ServerLog;
