import React, { useEffect, useState } from 'react';
import { HTMLTable, Switch, Icon, Intent, H6 } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';
const ServerLogFancy = observer(props => {

    const [fancyLog, setFancyLog] = useState([]);
    const [showError, setShowError] = useState(true);
    const [showTrace, setShowTrace] = useState(true);
    const [showWarn, setShowWarn] = useState(true);
    const [showInfo, setShowInfo] = useState(true);
    const [revert, setRevert] = useState(false);

    useEffect(() => {
        processLog();
    }, [showError, showTrace, revert]);

    function processLog() {
        let result = [];
        props.log.split('\n').slice(1).slice(0, -1).map(string => {
            let arr = string.split('|');
            result.push({
                date: arr[0],
                level: arr[1],
                module: arr[2],
                message: arr[3],
            })
        });

        if (!showTrace) {
            result = result.filter(str => str.level !== 'TRACE');
        }
        if (!showError) {
            result = result.filter(str => str.level !== 'ERROR');
        }
        if (!showWarn) {
            result = result.filter(str => str.level !== 'WARN');
        }
        if (!showInfo) {
            result = result.filter(str => str.level !== 'INFO');
        }

        if (revert) {
            result.reverse();
        }

        setFancyLog(result);
    }

    const options = <>
        <div>
            <Switch checked={showError} label="ERROR" onChange={(_) => setShowError(!showError)} />
            <Switch checked={showTrace} label="TRACE" onChange={(_) => setShowTrace(!showTrace)} />
            <Switch checked={showWarn} label="WARN" onChange={(_) => setShowWarn(!showWarn)} />
            <Switch checked={showInfo} label="INFO" onChange={(_) => setShowInfo(!showInfo)} />

            <Switch checked={revert} label="В обратном порядке" onChange={(_) => setRevert(!revert)} />
        </div>
        <H6>Всего: {fancyLog.length}</H6></>

    const trace = <><Icon icon="tick" intent={Intent.SUCCESS} /><span> TRACE</span></>
    const error = <><Icon icon="error" intent={Intent.DANGER} /><span> ERROR</span></>
    const warn = <><Icon icon="error" intent={Intent.WARNING} /><span> WARN</span></>
    const info = <><Icon icon="info-sign" intent={Intent.PRIMARY} /><span> INFO</span></>

    const fancyTable = <>
        <HTMLTable condensed interactive={true}>
            <thead>
                <th>Уровень</th>
                <th>Дата</th>
                <th>Модуль</th>
                <th>Сообщение</th>
            </thead>
            <tbody>
                {(fancyLog.map(str => {
                    return <tr>
                        <td style={{whiteSpace: "nowrap"}}>{str.level === 'TRACE' && trace}{str.level === 'ERROR' && error}
                        {str.level === 'WARN' && warn}{str.level === 'INFO' && info}</td>
                        <td style={{whiteSpace: "nowrap"}}>{str.date}</td>
                        <td style={{whiteSpace: "nowrap"}}>{str.module}</td>
                        <td>{str.message}</td>
                    </tr>
                }))}
            </tbody>
        </HTMLTable>
    </>


    return (<>
        {options}
        {fancyTable}
    </>
    );
});

export default ServerLogFancy;
