import { Breadcrumb, Breadcrumbs, HTMLTable } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';
import React, { useEffect, useState } from 'react';
import { useHistory } from 'react-router-dom';
import { useStores } from '../hooks/useStores';

const ServerLogs = observer(props => {

    let history = useHistory();
    const { rootStore } = useStores();

    const [logs, setLogs] = useState([]);

    useEffect(() => {
        getLogs();
        console.log(logs)
    }, []);

    const BREADCRUMBS = [
        { href: "/logs", icon: "folder-close", text: "Логи" },
    ];

    function getLogs() {
        const req = { AllFiles: true };
        rootStore.loginStore.apiAuthRequest(req, "api-log-getfileslist", (res) => { setLogs(res.FilesList) });
    }

    function formatBytes(bytes, decimals = 2) {
        if (bytes === 0) return '0 байт';

        const k = 1024;
        const dm = decimals < 0 ? 0 : decimals;
        const sizes = ['байт', 'КБ', 'МБ', 'ГБ', 'TB', 'PB', 'EB', 'ZB', 'YB'];

        const i = Math.floor(Math.log(bytes) / Math.log(k));

        return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
    }

    const renderCurrentBreadcrumb = ({ text, ...restProps }) => {
        return <Breadcrumb {...restProps}>{text}</Breadcrumb>;
    };

    return (<>
        <Breadcrumbs
            currentBreadcrumbRenderer={renderCurrentBreadcrumb}
            items={BREADCRUMBS}
        />
        <HTMLTable interactive={true}>
            <thead>
                <td>Имя файла</td>
                <td>Размер</td>
                <td>Дата модификации</td>
            </thead>
            <tbody>
                {logs.map(l =>
                    <tr onClick={(e) => history.push(`/logs/${l.FileName}`)}>
                        <td>{l.FileName}</td>
                        <td>{formatBytes(l.FileSize)}</td>
                        <td>{new Date(l.LastModifyDate).toLocaleDateString()} {new Date(l.LastModifyDate).toLocaleTimeString()}</td>
                    </tr>)}
            </tbody>
        </HTMLTable>
    </>
    );
});

export default ServerLogs;
