import React from 'react';
import {
    Button,
    Navbar,
    NavbarGroup,
    NavbarHeading,
    NavbarDivider,
    Classes,
    Alignment,
    Menu,
    MenuItem,
    Popover,
    Position,
} from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useHistory, useLocation } from 'react-router-dom';
import { useStores } from '../hooks/useStores';
import { getHostname } from '../utils/hostname';
import Feedback from './Feedback';

const TopNavbar = observer(props => {
    let history = useHistory();
    let location = useLocation();

    const { rootStore } = useStores();

    const { server, logout, isLoggedIn, username, logoutToDefault } = rootStore.loginStore;
    const { serverInfo } = rootStore.infoStore;
    let { switchTheme, darkTheme } = rootStore.localStore;

    const profileMenu = (
        <Menu>
            <MenuItem icon="user" text="Профиль" onClick={() => history.push('/profile')} />
            {server !== process.env.REACT_APP_API && (
                <MenuItem
                    icon="log-out"
                    text={`Вернуться на ${getHostname(process.env.REACT_APP_API)}`}
                    onClick={handleLogoutToDefault}
                />
            )}
            <MenuItem icon="log-out" text="Выйти" onClick={handleLogout} />
        </Menu>
    );

    const authMenu = (
        <Popover content={profileMenu} position={Position.BOTTOM}>
            <Button className={Classes.MINIMAL} icon="user" text={username} rightIcon="caret-down" />
        </Popover>
    );

    const unAuth = (
        <>
            {location.pathname === '/login' || location.pathname === '/clogin' ? null : (
                <Button className={Classes.MINIMAL} icon="user" text="Войти" onClick={() => history.push('/login')} />
            )}
        </>
    );

    function handleLogoutToDefault() {
        logoutToDefault();
        history.push('/');
    }

    function handleLogout() {
        logout();
        history.push('/');
    }

    function isNewYear() {
        const currentDate = new Date();
        if (
            (currentDate.getMonth() === 11 && currentDate.getDate() >= 25) ||
            (currentDate.getMonth() === 0 && currentDate.getDate() <= 13)
        ) {
            return true;
        }
        return false;
    }

    return (
        <Navbar className={'bp3-dark'}>
            <NavbarGroup align={Alignment.LEFT}>
                <NavbarHeading>
                    <div>
                        <img
                            src={`${process.env.PUBLIC_URL}/images/dew_logo.svg`}
                            alt=""
                            height="18px"
                            style={{ marginBottom: '-3px' }}></img>
                        {isNewYear() && (
                            <img
                                src={`${process.env.PUBLIC_URL}/images/santa_hat.svg`}
                                alt=""
                                height="15px"
                                style={{
                                    position: 'absolute',
                                    top: '5px',
                                    left: '50px',
                                    transform: 'rotate(0.01turn)',
                                }}></img>
                        )}
                    </div>
                    <div className={'bp3-text-muted bp3-text-small'}>{getHostname(server)}</div>
                </NavbarHeading>
                <NavbarDivider />
                <Button className={Classes.MINIMAL} icon="home" text="Главная" onClick={() => history.push('/')} />
                <Feedback />
            </NavbarGroup>
            <NavbarGroup align={Alignment.RIGHT}>
                <Button className={Classes.MINIMAL} icon={darkTheme ? 'flash' : 'moon'} onClick={() => switchTheme()} />
                {isLoggedIn && <NavbarDivider />}
                {isLoggedIn ? authMenu : !!serverInfo.ServerNameFull ? unAuth : null}
            </NavbarGroup>
        </Navbar>
    );
});

export default TopNavbar;
