import React, { useEffect } from 'react';
import { H1, HTMLTable, Tab, Tabs, Tag, Switch } from '@blueprintjs/core';
import { observer } from 'mobx-react-lite';import { useStores } from '../hooks/useStores';

const UserInfo = observer(props => {

    const { rootStore } = useStores();
    const { userInfo, getUserInfo, isAdmin, session } = rootStore.loginStore;
    let { changeThemeOnTime, setChangeThemeOnTime } = rootStore.localStore;

    useEffect(() => {
        getUserInfo();
    }, []);

    let date = withoutTime(userInfo.BIRTH_DATE);
    let today = withoutTime(new Date());

    let cake = date.valueOf() === today.valueOf() ? " 🎂" : null;

    function withoutTime(datetime) {
        var d = new Date(datetime);
        d.setHours(0, 0, 0, 0);
        return d;
    }

    const info = <>
        <HTMLTable>
            <tbody>
                <tr>
                    <td>Логин</td>
                    <td>{userInfo.U_NAME}</td>
                </tr>
                {isAdmin &&
                    <tr>
                        <td>Сессия</td>
                        <td><code>{session}</code></td>
                    </tr>}
                <tr>
                    <td>Полное имя</td>
                    <td>{userInfo.U_FULLNAME}</td>
                </tr>
                <tr>
                    <td>Пол</td>
                    <td>{userInfo.U_SEX}</td>
                </tr>
                <tr>
                    <td>Почта</td>
                    <td>{userInfo.U_EMAIL}</td>
                </tr>
                <tr>
                    <td>Телефон</td>
                    <td>{userInfo.U_PHONE_NUMS}</td>
                </tr>
                <tr>
                    <td>Дата рождения</td>
                    <td>{date.toLocaleDateString()}{cake}</td>
                </tr>
                <tr>
                    <td>Офис</td>
                    <td>{userInfo.UX_OFFICE}</td>
                </tr>
                <tr>
                    <td>Комментарий</td>
                    <td>{userInfo.UX_DESCRIPTION}</td>
                </tr>
            </tbody>
        </HTMLTable>
    </>

    const perms = <p>{!!userInfo.PermissionNames ? userInfo.PermissionNames.map(p => `${p}, `) : null}</p>;
    const permsCaption = <>Разрешения <Tag minimal={true}>{!!userInfo.PermissionNames ? userInfo.PermissionNames.length : 0}</Tag></>

    const misc = <Switch checked={changeThemeOnTime} label="Менять тему в зависимости от времени суток" onChange={(_) => setChangeThemeOnTime(!changeThemeOnTime)} />

    return (<>
        <H1>{userInfo.U_FULLNAME}</H1>
        <Tabs id="Tabs">
            <Tab id="info" title="Информация" panel={info} />
            <Tab id="perms" title={permsCaption} panel={perms} />
            <Tab id="misc" title="Всякая фигня" panel={misc} />
        </Tabs>

    </>
    );
});

export default UserInfo;
