import { H1, TextArea } from '@blueprintjs/core';
import 'katex/dist/katex.min.css';
import { observer } from 'mobx-react-lite';import React, { useState } from 'react';
import TeX from '@matejmazur/react-katex';
import ReactMarkdown from 'react-markdown';
import math from 'remark-math';
import styled from 'styled-components';
import gfm from 'remark-gfm';
import { Prism as SyntaxHighlighter } from 'react-syntax-highlighter';
//import { dark } from 'react-syntax-highlighter/dist/esm/styles/prism';

const MarkdownView = ({ md, className }) => {
    const renderers = {
        inlineMath: ({ value }) => <TeX math={value} />,
        math: ({ value }) => <TeX block math={value} />,
        code: ({ language, value }) => {
            return <SyntaxHighlighter language={language} children={value} />;
        },
    };
    return <ReactMarkdown plugins={[gfm, math]} renderers={renderers} children={md} className={className} />;
};

const StyledMarkdownView = styled(MarkdownView)`
    & code,
    & pre {
        background-color: #f8f8f8;
    }
    & pre,
    & output {
        margin: 1.2em 0;
        position: relative;
    }
    & pre > code,
    & output {
        border-radius: 2px;
        display: block;
    }
    & pre > code,
    & output::after {
        -moz-osx-font-smoothing: initial;
        -webkit-font-smoothing: initial;
    }
    & code {
        border-radius: 2px;
        color: #e96900;
        margin: 0 2px;
        padding: 3px 5px;
        white-space: pre-wrap;
    }
    & > :not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) code {
        font-size: 0.8rem;
    }
    & pre {
        padding: 0 1.4rem;
        line-height: 1.5rem;
        overflow: auto;
        word-wrap: normal;
    }
    & pre > code {
        color: #525252;
        font-size: 0.8rem;
        padding: 2.2em 5px;
        line-height: inherit;
        margin: 0 2px;
        max-width: inherit;
        overflow: inherit;
        white-space: inherit;
    }
    & table {
        border-collapse: collapse;
        border-spacing: 0;
        display: block;
        margin-bottom: 1rem;
        overflow: auto;
        width: 100%;
    }
`;

const Markdown = observer(props => {
    const [md, setMd] = useState(`

# Hello!

После модификации конфигурации в системе **"1С Предприятие"** подсистема _"Управление закупками"_ на базе ППИАС будет иметь возможность обработки REST запросов которые уже будут адресованы непосредственно к самой платформе. Ниже приведен перечень доступных API:

- api-logistic-finderpitem
- api-logistic-chechkstatuser
- api-logistic-createorder
- api-logistic-finderpskladcount
- api-logistic-finderppurchdays

Например, запрос к API \`\`\`api-logistic-finderpitem\`\`\`, где в качестве основного входного параметра необходимо передать поле $\\forall x \\in X, \\exists y \\leq \\epsilon$
, вернет слеующую:

\`\`\` json
{
  ErrorMessage : "Найден один элемент",
  ResultList : [
    {
      ID: "XP-0001",
      Name: "Винт M4х10.21",
      NameGOST: "Винт M4х10.21 DIN",
      EdIzm: "ШТ",
      FoundMask: "",
      FoundViaERP = true
    },
    ...
  ]
}
\`\`\`

$$-b \\pm \\sqrt{b^2 - 4ac} \\over 2a$$
`);

    return (
        <>
            <H1>Тест редактора Markdown</H1>
            <div style={{ display: 'flex' }}>
                <TextArea fill={true} onChange={e => setMd(e.target.value)} value={md} style={{ maxWidth: '50%' }} />
                <div style={{ margin: '1rem', maxWidth: '50%' }}>
                    <StyledMarkdownView md={md} />
                </div>
            </div>
        </>
    );
});

export default Markdown;
