import { makeAutoObservable, when } from 'mobx';
import moment from 'moment';

class LocalStore {
    darkTheme = false;
    changeThemeOnTime = true;
    objectsPerPage = 10;

    time = moment();

    constructor(rootStore, period = 1000 * 60) {
        this.rootStore = rootStore;
        makeAutoObservable(this);

        this.interval = setInterval(() => this.clockTick(), period);
        if (localStorage.getItem('theme') === 'dark') {
            this.darkTheme = true;
        }

        if (localStorage.getItem('changeThemeOnTime') === 'no') {
            this.changeThemeOnTime = false;
        }

        if (this.changeThemeOnTime) {
            when(
                () => this.time.isAfter(moment('22:00', "hh:mm")),
                () => {
                    localStorage.setItem('theme', 'dark');
                    this.darkTheme = true;
                }
            )
            when(
                () => this.time.isAfter(moment('06:00', "hh:mm")) && this.time.isBefore(moment('22:00', "hh:mm")),
                () => {
                    localStorage.setItem('theme', 'light');
                    this.darkTheme = false;
                }
            )
        }

        let number = Number(localStorage.getItem('objectsPerPage'));

        if (Number.isInteger(number) && number > 0) {
            this.objectsPerPage = number;
        } else {
            localStorage.removeItem('objectsPerPage');
        }

        if (localStorage.getItem('changeThemeOnTime') === 'no') {
            this.changeThemeOnTime = false;
        }
    }

    clockTick(newTime = moment()) {
        this.time = newTime;
    }

    switchTheme = () => {
        if (this.darkTheme) {
            localStorage.setItem('theme', 'light');
            this.darkTheme = false;
        } else {
            localStorage.setItem('theme', 'dark');
            this.darkTheme = true;
        }
    }

    setChangeThemeOnTime = (change) => {
        if (change) {
            localStorage.setItem('changeThemeOnTime', 'yes');
            this.changeThemeOnTime = true;
        } else {
            localStorage.setItem('changeThemeOnTime', 'no');
            this.changeThemeOnTime = false;
        }
    }

    setObjectsPerPage = (number) => {
        if (Number.isInteger(number) && number > 0) {
            localStorage.setItem('objectsPerPage', number);
            this.objectsPerPage = number;
        }
    }
}

export default LocalStore;
