import { makeAutoObservable } from "mobx";

class ServerStore {
    servers = [];

    constructor(rootStore) {
        this.rootStore = rootStore;
        makeAutoObservable(this);
    }

    getServers = () => {
        let s = JSON.parse(localStorage.getItem('servers'));
        if (!Array.isArray(s)) return;
        this.servers = s;
    };

    addServer = (server, status, message) => {
        //toto pамена
        if (this.servers.findIndex(x => x.server.toLowerCase() === server.trim().toLowerCase()) >= 0) {
            return;
        }

        this.servers.push({
            server: server.trim(),
            status: status,
            result: message,
        });
        this.checkServer(server);
        localStorage.setItem('servers', JSON.stringify(this.servers));
    };

    clearServers = () => {
        this.servers = [];
        localStorage.setItem('servers', JSON.stringify(this.servers));
    };

    removeServer = server => {
        let foundIndex = this.servers.findIndex(x => x.server === server.server);
        this.servers.splice(foundIndex, 1);
        localStorage.setItem('servers', JSON.stringify(this.servers));
    };

    checkServer = server => {
        let checked = {
            server: server,
            date: new Date().toUTCString(),
        };

        let msg;

        this.rootStore.loginStore.apiUnAuthCustomRequest(
            null,
            'sys-status',
            checked.server,
            res => {
                checked.status = true;
                msg = res.ServerNameShort;
            },
            err => {
                checked.status = false;
                msg = err;
            },
            () => {
                checked.result = msg;
                let foundIndex = this.servers.findIndex(x => x.server === checked.server);
                this.servers[foundIndex] = checked;
                localStorage.setItem('servers', JSON.stringify(this.servers));
            }
        );
    };

    checkServers = () => {
        let checked = this.servers.map(s => this.checkServer(s.server));
        localStorage.setItem('servers', JSON.stringify(checked));
    };
}

export default ServerStore;
